      subroutine hana_minimize
c
c controls depth weight minimization
c
      implicit none
c
      include'hec_ana.inc'
      include'hec_ana_runh.inc'      ! run header ntuple common
      include'hec_ana_evt.inc'       ! event ntuple common 
c
      include'hana.inc'
      include'hana_card.inc'
c
c local variables
c
      external minfxn
      integer ierflg, i
      real*8 arglis(10), chi2, dum, out_par
      integer nprm(maxn_z+1)
      real*8 vstrt(maxn_z+1),stp(maxn_z+1),zero
      character*3 pnam(maxn_z+1)
c
      data pnam /'alp','dw1','dw2','dw3'/
c
c If minimization is not asked for in the datacard, then return.
c
      if (minuit_set .eq. 0) return
c
c If individual sigma cuts for each run haven't been set in the 
c  data card, then set them to the global datacard values:
c
      if (sig_rcut_lo(irun) .eq. 0.) sig_rcut_lo(irun)= sig_cut_lo
      if (sig_rcut_hi(irun) .eq. 0.) sig_rcut_hi(irun)= sig_cut_hi
c
      nprm(1) = 1
      vstrt(1) = dble(abs(alpha_min))
      stp(1) = vstrt(1)/100.D0
      if (alpha_switch(irun) .eq. 0) stp(1) = 0.
c
c depths 1,2 and 3
c  
      do i = 2, maxn_z+1
        nprm(i) = i
        vstrt(i) = 1.D0
        stp(i) = vstrt(i)/100.D0
        if (depth_switch(irun,i-1) .eq. 0) stp(i) = 0.D0
      enddo
c
      zero=0.
c
c intialize minuit (unit no. for input, unit no for output, 
c                   unit no for save)
c
      call mninit(5,6,7)
c
c define a minuit parameter (the index no. for the parameter, 
c       character name of parameter, starting value, step, low bound,
c       high bound, error return code (>0 if failed) )
c        if both bounds=0.0, the parameter is unbounded (recommended)
c
      do i=1,maxn_z+1
        call mnparm(nprm(i),pnam(i),vstrt(i),stp(i),zero,zero,ierflg)
        if(ierflg.ne.0) then
          print *,'run_minimize: unable to define parameter no. ',i
          stop
        endif
      enddo
c
c set the title in minuit
c
      call mnseti('Minimization to obtain depth weights')
c
c --- do fit in minuit (name of fxn to be minimized, 
c         minuit control command,
c         array of numeric arguments, no. of numeric args, 
c         error return code)
c  migrad==> minimization
c
      if (minuit_set .eq. 1) then
        call mnexcm(minfxn,'migrad',arglis,0,ierflg)
        print *,'***'
        print *,'*** Calling migrad minimization'
        print *,'***'
      elseif (minuit_set .eq. 2) then
        call mnexcm(minfxn,'simplex',arglis,0,ierflg)
        print *,'***'
        print *,'*** Calling simplex minimization'
        print *,'***'
      endif
      call mnstat(chi2,dum,dum,dum,dum,dum)
      print *,'run_minimize: error flag from minuit: ',ierflg
      minuit_error_flag = ierflg
      print *,'run_minimize: chi squared: ', chi2
c
c --- get parameters from fit
c
      call mnpout(1,pnam(1),out_par,dum,dum,dum,ierflg)
      alpha_min = sngl(out_par)
      print *,'hana_minimize: alpha_min = ',alpha_min
c
      do i = 2, maxn_z+1
        call mnpout(i,pnam(i),out_par,dum,dum,dum,ierflg)
        depth_min(i-1) = sngl(out_par)
        print *,'hana_minimize: depth_min(',i-1,') = ',depth_min(i-1)
      enddo
c
      return
      end      

