      program hec_ana
c
c authors: M. Dobbs and D. O'Neil          October 1998
c
c program to access data from standard ntuple output of 
c hec_adc package and produce a note-worthy analysis
c
      implicit none
c
c system commons
c
      include'hec_ana.inc'           ! general parameter common
      include'hec_ana_card.inc'      ! general datacard common
      include'hec_ana_evt.inc'       ! event ntuple common 
      include'hec_ana_paw.inc'       ! paw common
      include'hec_ana_runh.inc'      ! run header ntuple common
c
      include'hana.inc'
      include'hana_card.inc'
c
c local variables
c
      integer i, icycle
      real beame_tmp
c
c general initialization
c
      call hec_ana_ini
c
c hana initialization
c
      call hana_ini
c
c datacard init.
c
      call ffgo
c
c begin loop over runs
c
      do irun = 1, nruns
c
c run intialization (open hbook file etc.)
c and hana run initialization
c 
        call hec_ana_run_ini
        call hana_run_ini
c
c get run header ntuple information 
c
        call hec_ana_runh
c
c - pass1
c
        ievt_count = 0
        if (pass_card(1) .ne. 0) then
          i_event = 0
          do while (i_event .le. min(nevents,maxn_evts) 
     +      .and. ievt_count .le. min(maxevt,maxn_evts))
            i_event = i_event + 1
c
            call hec_ana_evt
            call hana_search_evt
c
c call hana debugging routine
c
            if (debug .ge. 1) call hana_debug
c
c put hana cluster finder in here
c
          enddo                 ! do i_event
c
c Analyse the search results and write results to log file.
c
          call hana_search_run
c
c If requested in datacard, choose cluster based on search results.
c    Only possible if pass 1 is turned on!
c
          call hana_auto_cluster
        endif
c
c If requested in datacard, set the subcluster equal to the cluster.
c    This call has to come after the search, just in case the cluster
c    is chosen using   hana_auto_cluster.
c
        call hana_auto_subcluster
c
c - pass2 - hana makes clusters
c
        ievt_count = 0
        if (pass_card(2) .ne. 0) then
          i_event = 0
          do while (i_event .le. min(nevents,maxn_evts) 
     +      .and. ievt_count .le. min(maxevt,maxn_evts))
            i_event = i_event + 1
c
c hana zero clusters
c
            if (i_event .eq. 1) 
     +         call vzero(cluster,maxn_evts*maxn_z*maxn_mod)
c
c get next event into memory
c
            call hec_ana_evt            
c
c hana does clustering here
c
            call hana_cluster
          enddo                 ! do i_event
c
c hana makes non-optimized histogram
c
          call hcdir('//gauss',' ')
          call hana_histogram(1000)
          call hrout(0,icycle,' ')
c
c hana finds optimum depth weights and uses them to fill histos
c
          call hana_minimize
          call hana_histogram(2000)
          call hrout(0,icycle,' ')
          signal_mean = gau_mean
          signal_mean_error = gau_mean_err
          signal_sigma = gau_sigma
          signal_sigma_error = gau_sigma_err
        endif
        
c
c - pass3
c here hana passes over events to calculate noise
c
        if (noisetype .eq. 2) then
          beame_tmp = hec_beame
          call hana_open_noise
          call hec_ana_runh
          hec_beame = beame_tmp
        endif
c
        ievt_count = 0
        if (pass_card(3) .ne. 0) then
          i_event = 0
          do while (i_event .le. min(nevents,maxn_evts) 
     +      .and. ievt_count .le. min(maxevt,maxn_evts))
            i_event = i_event + 1
c
c hana zero clusters
c
            if (i_event .eq. 1) 
     +         call vzero(cluster,maxn_evts*maxn_z*maxn_mod)
c
c read in next event
c
            call hec_ana_evt
c
c for special noise analysis, reset triggers, turn off subcluster
c cut, do noise cluster
c
            if (hec_trig(5) .eq. 1) then
              do i = 1, 5
                hec_trig(i) = trig_set(i)
              enddo
              subclus_hits(irun) = 0
              call hana_cluster
            endif
            
          enddo                 ! do i_event
c
          call hcdir('//gauss',' ')
          call hana_histogram(3000)
          call hrout(0,icycle,'N')
          if (noisetype .eq. 1) then 
            noise = stat_sigma
            noise_error = stat_sigma_error
          elseif (noisetype .eq. 2) then
            noise = gau_sigma
            noise_error = gau_sigma_err
          else
            noise = 0.
            noise_error = 0.
          endif
        endif
c
c Write out results (only if there are any!)
c 
        if (pass_card(2) .ne. 0) call hana_fillvec
c
c terminate run
c
        call hec_ana_run_ter
c
c end loop over runs
c
      enddo            ! do irun = 1, nruns
c
c terminate hana
c
      call hana_ter
c
      end





